# 📘 Skoobpy 

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

Gives you methods to extract the users' data from [Skoob](skoob.com.br).

## ⚙️ Installation

You can install Skoobpy from PyPI:

```bash
pip install skoobpy
```

## 💻 How to Use

You can run it as a module in a command line as `skoobpy` followed by an `user_id`. It is going to generate a csv file named `books_user_id.csv` with all informations of user's desired books.

    $ python -m skoopy <user_id>

## 📑 Release History

* 0.1.0
    * First version - extract users' desired books in CSV file

## ⚖️ License

Distributed under the MIT license. See [`LICENSE`](https://github.com/Diegoslourenco/skoopy/blob/main/LICENSE) for more information.

## 🚧🚀 Contributing


Feel free to contribute with anything.

[In case of any doubt, see this.](https://github.com/firstcontributions/first-contributions)

To start with development, don't forget to install:

```python
$ pip install -r requirements.txt
```
